=== modified file 'client/drizzle.cc'
--- client/drizzle.cc	2010-10-06 17:34:30 +0000
+++ client/drizzle.cc	2010-10-25 10:22:50 +0000
@@ -340,7 +340,7 @@
 static uint32_t delimiter_length= 1;
 unsigned short terminal_width= 80;
 
-int drizzleclient_real_query_for_lazy(const char *buf, int length,
+int drizzleclient_real_query_for_lazy(const char *buf, size_t length,
                                       drizzle_result_st *result,
                                       uint32_t *error_code);
 int drizzleclient_store_result_for_lazy(drizzle_result_st *result);
@@ -2669,7 +2669,7 @@
  The different commands
 ***************************************************************************/
 
-int drizzleclient_real_query_for_lazy(const char *buf, int length,
+int drizzleclient_real_query_for_lazy(const char *buf, size_t length,
                                       drizzle_result_st *result,
                                       uint32_t *error_code)
 {

=== modified file 'client/drizzledump.cc'
--- client/drizzledump.cc	2010-10-23 10:43:00 +0000
+++ client/drizzledump.cc	2010-10-26 23:46:28 +0000
@@ -227,7 +227,7 @@
     }
     catch (...)
     {
-      std::cout << _("Error inserting into destnation database") << std::endl;
+      std::cout << _("Error inserting into destination database") << std::endl;
       if (not ignore_errors)
         maybe_exit(EX_DRIZZLEERR);
     }

=== modified file 'client/drizzledump_data.cc'
--- client/drizzledump_data.cc	2010-10-21 18:57:05 +0000
+++ client/drizzledump_data.cc	2010-10-26 23:46:28 +0000
@@ -473,17 +473,17 @@
   }
 
   os << std::endl;
-  os << ") ENGINE=" << obj.engineName << " ";
+  os << ") ENGINE='" << obj.engineName << "' ";
   if (obj.autoIncrement > 0)
   {
     os << "AUTO_INCREMENT=" << obj.autoIncrement << " ";
   }
 
-  os << "COLLATE = " << obj.collate;
+  os << "COLLATE='" << obj.collate << "'";
 
   if (not obj.comment.empty())
   {
-    os << " COMMENT = '" << obj.comment << "'";
+    os << " COMMENT='" << obj.comment << "'";
   }
 
   os << ";" << std::endl << std::endl;

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2010-10-26 19:14:30 +0000
+++ drizzled/drizzled.cc	2010-10-27 18:04:38 +0000
@@ -787,7 +787,7 @@
 
 static void check_limits_map(uint32_t in_max_allowed_packet)
 {
-  global_system_variables.max_allowed_packet= (1024*1024L);
+  global_system_variables.max_allowed_packet= (64*1024*1024L);
   if (in_max_allowed_packet < 1024 || in_max_allowed_packet > 1024*1024L*1024L)
   {
     cout << N_("Error: Invalid Value for max_allowed_packet");
@@ -1140,7 +1140,16 @@
        it != in_options.end();
        ++it)
   {
-    defaults_file_list.push_back(*it);
+    fs::path p(*it);
+    if (fs::is_regular_file(p))
+      defaults_file_list.push_back(*it);
+    else
+    {
+      errmsg_printf(ERRMSG_LVL_ERROR,
+                  _("Defaults file '%s' not found\n"), (*it).c_str());
+      unireg_abort(1);
+    }
+
   }
 }
 
@@ -1291,7 +1300,7 @@
   N_("The maximum length of the result of function  group_concat."))
   ("join-buffer-size", po::value<uint64_t>(&global_system_variables.join_buff_size)->default_value(128*1024L)->notifier(&check_limits_join_buffer_size),
   N_("The size of the buffer that is used for full joins."))
-  ("max-allowed-packet", po::value<uint32_t>(&global_system_variables.max_allowed_packet)->default_value(1024*1024L)->notifier(&check_limits_map),
+  ("max-allowed-packet", po::value<uint32_t>(&global_system_variables.max_allowed_packet)->default_value(64*1024*1024L)->notifier(&check_limits_map),
   N_("Max packetlength to send/receive from to server."))
   ("max-connect-errors", po::value<uint64_t>(&max_connect_errors)->default_value(MAX_CONNECT_ERRORS)->notifier(&check_limits_mce),
   N_("If there is more than this number of interrupted connections from a "
@@ -1422,7 +1431,6 @@
     }
   }
 
-  process_defaults_files();
   /* TODO: here is where we should add a process_env_vars */
 
   /* We need a notify here so that plugin_init will work properly */
@@ -1438,6 +1446,25 @@
                   internal::my_progname, err.what());
     unireg_abort(1);
   }
+
+  process_defaults_files();
+
+  /* Process with notify a second time because a config file may contain
+     plugin loader options */
+
+  try
+  {
+    po::notify(vm);
+  }
+  catch (po::validation_error &err)
+  {
+    errmsg_printf(ERRMSG_LVL_ERROR,
+                  _("%s: %s.\n"
+                    "Use --help to get a list of available options\n"),
+                  internal::my_progname, err.what());
+    unireg_abort(1);
+  }
+
   /* At this point, we've read all the options we need to read from files and
      collected most of them into unknown options - now let's load everything
   */
@@ -1899,7 +1926,7 @@
    N_("Max packetlength to send/receive from to server."),
    (char**) &global_system_variables.max_allowed_packet,
    (char**) &max_system_variables.max_allowed_packet, 0, GET_UINT32,
-   REQUIRED_ARG, 1024*1024L, 1024, 1024L*1024L*1024L, MALLOC_OVERHEAD, 1024, 0},
+   REQUIRED_ARG, 64*1024*1024L, 1024, 1024L*1024L*1024L, MALLOC_OVERHEAD, 1024, 0},
   {"max_connect_errors", OPT_MAX_CONNECT_ERRORS,
    N_("If there is more than this number of interrupted connections from a "
       "host this host will be blocked from further connections."),

=== modified file 'libdrizzle/common.h'
--- libdrizzle/common.h	2010-09-28 07:47:48 +0000
+++ libdrizzle/common.h	2010-10-27 06:36:38 +0000
@@ -33,6 +33,7 @@
 #include <string.h>
 #include <sys/uio.h>
 #include <unistd.h>
+#include <signal.h>
 
 #include "drizzle_local.h"
 #include "conn_local.h"

=== modified file 'libdrizzle/conn.c'
--- libdrizzle/conn.c	2010-09-28 07:47:48 +0000
+++ libdrizzle/conn.c	2010-10-27 06:36:38 +0000
@@ -1007,7 +1007,7 @@
   while (con->buffer_size != 0)
   {
   
-    write_size = send(con->fd,(char *) con->buffer_ptr, con->buffer_size,0);
+    write_size = send(con->fd,(char *) con->buffer_ptr, con->buffer_size, 0);
 
     drizzle_log_crazy(con->drizzle, "write fd=%d return=%zd errno=%d", con->fd,
                       write_size, errno);

=== modified file 'libdrizzle/drizzle.c'
--- libdrizzle/drizzle.c	2010-09-28 07:47:48 +0000
+++ libdrizzle/drizzle.c	2010-10-27 06:36:38 +0000
@@ -67,6 +67,11 @@
   if ( WSAStartup( MAKEWORD(2,2), &wsaData ) != 0 )
     printf("Error at WSAStartup()\n");
 #endif
+  struct sigaction act;
+
+  act.sa_handler = SIG_IGN;
+  sigaction(SIGPIPE, &act, NULL);
+
   if (drizzle == NULL)
   {
     drizzle= malloc(sizeof(drizzle_st));

=== modified file 'plugin/mysql_protocol/mysql_protocol.cc'
--- plugin/mysql_protocol/mysql_protocol.cc	2010-10-25 20:36:07 +0000
+++ plugin/mysql_protocol/mysql_protocol.cc	2010-10-27 18:03:49 +0000
@@ -206,8 +206,6 @@
       return false;                       // We have to close it.
 
     net.error= 0;
-    *packet_length= 0;
-    return true;
   }
 
   *l_packet= (char*) net.read_pos;
@@ -420,6 +418,8 @@
 
   drizzleclient_net_write_command(&net,(unsigned char) 255, (unsigned char*) "", 0, (unsigned char*) err, length);
 
+  drizzleclient_net_flush(&net);
+
   session->main_da.can_overwrite_status= false;
 }
 

=== modified file 'plugin/mysql_protocol/net_serv.cc'
--- plugin/mysql_protocol/net_serv.cc	2010-05-19 01:22:29 +0000
+++ plugin/mysql_protocol/net_serv.cc	2010-10-27 06:36:38 +0000
@@ -158,7 +158,7 @@
   if (length >= net->max_packet_size)
   {
     /* @todo: 1 and 2 codes are identical. */
-    net->error= 1;
+    net->error= 3;
     net->last_errno= ER_NET_PACKET_TOO_LARGE;
     my_error(ER_NET_PACKET_TOO_LARGE, MYF(0));
     return(1);
@@ -599,7 +599,7 @@
 my_real_read(NET *net, size_t *complen)
 {
   unsigned char *pos;
-  size_t length;
+  size_t length= 0;
   uint32_t i,retry_count=0;
   size_t len=packet_error;
   uint32_t remain= (net->compress ? NET_HEADER_SIZE+COMP_HEADER_SIZE :
@@ -674,6 +674,14 @@
       {
         if (drizzleclient_net_realloc(net,helping))
         {
+          /* Clear the buffer so libdrizzle doesn't keep retrying */
+          while (len > 0)
+          {
+            length= read(net->vio->sd, net->buff, min((size_t)net->max_packet, len));
+            assert((long)length > 0L);
+            len-= length;
+          }
+            
           len= packet_error;          /* Return error and close connection */
           goto end;
         }

=== modified file 'tests/r/drizzledump-max.result'
--- tests/r/drizzledump-max.result	2010-09-29 20:40:25 +0000
+++ tests/r/drizzledump-max.result	2010-10-26 23:46:28 +0000
@@ -75,7 +75,7 @@
 CREATE TABLE `t1` (
   `id` INT DEFAULT NULL,
   `name` VARCHAR(32) COLLATE utf8_general_ci DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t1` DISABLE KEYS;
 INSERT IGNORE INTO `t1` VALUES (1,'first value'),(2,'first value'),(3,'first value'),(4,'first value'),(5,'first value');
@@ -85,7 +85,7 @@
 CREATE TABLE `t2` (
   `id` INT DEFAULT NULL,
   `name` VARCHAR(32) COLLATE utf8_general_ci DEFAULT NULL
-) ENGINE=ARCHIVE COLLATE = utf8_general_ci;
+) ENGINE='ARCHIVE' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t2` DISABLE KEYS;
 INSERT IGNORE INTO `t2` VALUES (1,'first value'),(2,'first value'),(3,'first value'),(4,'first value'),(5,'first value');
@@ -95,7 +95,7 @@
 CREATE TABLE `t6` (
   `id` INT DEFAULT NULL,
   `name` VARCHAR(32) COLLATE utf8_general_ci DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t6` DISABLE KEYS;
 INSERT IGNORE INTO `t6` VALUES (1,'first value'),(2,'first value'),(3,'first value'),(4,'first value'),(5,'first value');
@@ -114,7 +114,7 @@
 CREATE TABLE `t1` (
   `id` INT DEFAULT NULL,
   `name` VARCHAR(32) COLLATE utf8_general_ci DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t1` DISABLE KEYS;
 INSERT INTO `t1` VALUES (1,'first value'),(2,'first value'),(3,'first value'),(4,'first value'),(5,'first value');
@@ -124,7 +124,7 @@
 CREATE TABLE `t2` (
   `id` INT DEFAULT NULL,
   `name` VARCHAR(32) COLLATE utf8_general_ci DEFAULT NULL
-) ENGINE=ARCHIVE COLLATE = utf8_general_ci;
+) ENGINE='ARCHIVE' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t2` DISABLE KEYS;
 INSERT INTO `t2` VALUES (1,'first value'),(2,'first value'),(3,'first value'),(4,'first value'),(5,'first value');
@@ -134,7 +134,7 @@
 CREATE TABLE `t6` (
   `id` INT DEFAULT NULL,
   `name` VARCHAR(32) COLLATE utf8_general_ci DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t6` DISABLE KEYS;
 INSERT INTO `t6` VALUES (1,'first value'),(2,'first value'),(3,'first value'),(4,'first value'),(5,'first value');

=== modified file 'tests/r/drizzledump.result'
--- tests/r/drizzledump.result	2010-09-29 20:40:25 +0000
+++ tests/r/drizzledump.result	2010-10-26 23:46:28 +0000
@@ -13,7 +13,7 @@
 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
 CREATE TABLE `t1` (
   `a` DECIMAL(64,20) DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 INSERT INTO `t1` VALUES ('1234567890123456789012345678901234567890.00000000000000000000'),('987654321098765432109876543210987654321.00000000000000000000');
 
@@ -29,7 +29,7 @@
 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
 CREATE TABLE ```a` (
   `i` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
@@ -76,7 +76,7 @@
 DROP TABLE IF EXISTS `t2`;
 CREATE TABLE `t2` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t2` DISABLE KEYS;
 INSERT INTO `t2` VALUES (4),(5),(6);
@@ -97,7 +97,7 @@
 DROP TABLE IF EXISTS `t1`;
 CREATE TABLE `t1` (
   `b` BLOB DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t1` DISABLE KEYS;
 INSERT INTO `t1` VALUES (0x602010000280100005E71A);
@@ -118,7 +118,7 @@
 DROP TABLE IF EXISTS `t1`;
 CREATE TABLE `t1` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t1` DISABLE KEYS;
 INSERT IGNORE INTO `t1` VALUES (1),(2),(3),(4),(5),(6);
@@ -798,7 +798,7 @@
   `F_cd00692c3bfe59267d5ecfac5310286c` INT DEFAULT NULL,
   `F_6faa8040da20ef399b63a72d0e4ab575` INT DEFAULT NULL,
   `F_fe73f687e5bc5280214e0486b273a5f9` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t1` DISABLE KEYS;
 INSERT INTO `t1` VALUES (NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);
@@ -823,7 +823,7 @@
 DROP TABLE IF EXISTS `t1`;
 CREATE TABLE `t1` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t1` DISABLE KEYS;
 INSERT INTO `t1` VALUES (1),(2),(3);
@@ -847,12 +847,12 @@
 DROP TABLE IF EXISTS `t1`;
 CREATE TABLE `t1` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 DROP TABLE IF EXISTS `t2`;
 CREATE TABLE `t2` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
@@ -862,12 +862,12 @@
 DROP TABLE IF EXISTS `t1`;
 CREATE TABLE `t1` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 DROP TABLE IF EXISTS `t2`;
 CREATE TABLE `t2` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
@@ -896,7 +896,7 @@
   `a` VARCHAR(30) NOT NULL COLLATE utf8_general_ci,
   `b` INT NOT NULL,
   PRIMARY KEY (`a`)
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 Error executing query: Table 'mysqldump_test_db.t\1' doesn't exist
 Error: Could not get data for table t\1
@@ -907,7 +907,7 @@
   `a` VARCHAR(30) NOT NULL COLLATE utf8_general_ci,
   `b` INT NOT NULL,
   PRIMARY KEY (`a`)
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 Error executing query: Table 'mysqldump_test_db.t\1' doesn't exist
 Error: Could not get data for table t\1
@@ -977,17 +977,17 @@
 DROP TABLE IF EXISTS `t3`;
 CREATE TABLE `t3` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 DROP TABLE IF EXISTS `t1`;
 CREATE TABLE `t1` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 DROP TABLE IF EXISTS `t2`;
 CREATE TABLE `t2` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
@@ -1054,7 +1054,7 @@
 CREATE TABLE `t1` (
   `a` INT DEFAULT NULL,
   `b` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t1` DISABLE KEYS;
 REPLACE INTO `t1` VALUES (1,1),(2,3),(3,4),(4,5);
@@ -1074,7 +1074,7 @@
 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
 CREATE TABLE `test` (
   `a` INT DEFAULT NULL
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;

=== modified file 'tests/r/func_compress.result'
--- tests/r/func_compress.result	2010-05-27 19:36:37 +0000
+++ tests/r/func_compress.result	2010-10-26 20:59:40 +0000
@@ -66,7 +66,7 @@
 NULL
 Warnings:
 Error	1259	ZLIB: Input data corrupted
-Error	1256	Uncompressed data size too large; the maximum size is 1048576 (based on max_allowed_packet). The length of uncompressed data may also be corrupted.
+Error	1256	Uncompressed data size too large; the maximum size is 67108864 (based on max_allowed_packet). The length of uncompressed data may also be corrupted.
 drop table t1;
 set @@max_allowed_packet=1048576*100;
 select compress(repeat('aaaaaaaaaa', IF(XXX, 10, 10000000))) is null;

=== modified file 'tests/r/func_str.result'
--- tests/r/func_str.result	2010-10-14 18:58:48 +0000
+++ tests/r/func_str.result	2010-10-26 20:59:40 +0000
@@ -287,7 +287,7 @@
 length(repeat("a",100000000))	length(repeat("a",1000*64))
 NULL	64000
 Warnings:
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select position("0" in "baaa" in (1)),position("0" in "1" in (1,2,3)),position("sql" in ("mysql"));
 position("0" in "baaa" in (1))	position("0" in "1" in (1,2,3))	position("sql" in ("mysql"))
 1	0	3
@@ -1374,7 +1374,7 @@
 repeat('hello', 4294967295)
 NULL
 Warnings:
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select repeat('hello', -4294967296);
 repeat('hello', -4294967296)
 
@@ -1382,7 +1382,7 @@
 repeat('hello', 4294967296)
 NULL
 Warnings:
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select repeat('hello', -4294967297);
 repeat('hello', -4294967297)
 
@@ -1390,7 +1390,7 @@
 repeat('hello', 4294967297)
 NULL
 Warnings:
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select repeat('hello', -18446744073709551615);
 repeat('hello', -18446744073709551615)
 
@@ -1401,7 +1401,7 @@
 repeat('hello', 18446744073709551615)
 NULL
 Warnings:
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select repeat('hello', -18446744073709551616);
 repeat('hello', -18446744073709551616)
 
@@ -1414,7 +1414,7 @@
 Warnings:
 Error	1292	Truncated incorrect DECIMAL value: ''
 Error	1292	Truncated incorrect DECIMAL value: ''
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select repeat('hello', -18446744073709551617);
 repeat('hello', -18446744073709551617)
 
@@ -1427,7 +1427,7 @@
 Warnings:
 Error	1292	Truncated incorrect DECIMAL value: ''
 Error	1292	Truncated incorrect DECIMAL value: ''
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select space(-1);
 space(-1)
 
@@ -1438,7 +1438,7 @@
 space(4294967295)
 NULL
 Warnings:
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select space(-4294967296);
 space(-4294967296)
 
@@ -1446,7 +1446,7 @@
 space(4294967296)
 NULL
 Warnings:
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select space(-4294967297);
 space(-4294967297)
 
@@ -1454,7 +1454,7 @@
 space(4294967297)
 NULL
 Warnings:
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select space(-18446744073709551615);
 space(-18446744073709551615)
 
@@ -1465,7 +1465,7 @@
 space(18446744073709551615)
 NULL
 Warnings:
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select space(-18446744073709551616);
 space(-18446744073709551616)
 
@@ -1478,7 +1478,7 @@
 Warnings:
 Error	1292	Truncated incorrect DECIMAL value: ''
 Error	1292	Truncated incorrect DECIMAL value: ''
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select space(-18446744073709551617);
 space(-18446744073709551617)
 
@@ -1491,7 +1491,7 @@
 Warnings:
 Error	1292	Truncated incorrect DECIMAL value: ''
 Error	1292	Truncated incorrect DECIMAL value: ''
-Warning	1301	Result of repeat() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of repeat() was larger than max_allowed_packet (67108864) - truncated
 select rpad('hello', -1, '1');
 rpad('hello', -1, '1')
 NULL
@@ -1502,7 +1502,7 @@
 rpad('hello', 4294967295, '1')
 NULL
 Warnings:
-Warning	1301	Result of rpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of rpad() was larger than max_allowed_packet (67108864) - truncated
 select rpad('hello', -4294967296, '1');
 rpad('hello', -4294967296, '1')
 NULL
@@ -1510,7 +1510,7 @@
 rpad('hello', 4294967296, '1')
 NULL
 Warnings:
-Warning	1301	Result of rpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of rpad() was larger than max_allowed_packet (67108864) - truncated
 select rpad('hello', -4294967297, '1');
 rpad('hello', -4294967297, '1')
 NULL
@@ -1518,7 +1518,7 @@
 rpad('hello', 4294967297, '1')
 NULL
 Warnings:
-Warning	1301	Result of rpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of rpad() was larger than max_allowed_packet (67108864) - truncated
 select rpad('hello', -18446744073709551615, '1');
 rpad('hello', -18446744073709551615, '1')
 NULL
@@ -1529,7 +1529,7 @@
 rpad('hello', 18446744073709551615, '1')
 NULL
 Warnings:
-Warning	1301	Result of rpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of rpad() was larger than max_allowed_packet (67108864) - truncated
 select rpad('hello', -18446744073709551616, '1');
 rpad('hello', -18446744073709551616, '1')
 NULL
@@ -1542,7 +1542,7 @@
 Warnings:
 Error	1292	Truncated incorrect DECIMAL value: ''
 Error	1292	Truncated incorrect DECIMAL value: ''
-Warning	1301	Result of rpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of rpad() was larger than max_allowed_packet (67108864) - truncated
 select rpad('hello', -18446744073709551617, '1');
 rpad('hello', -18446744073709551617, '1')
 NULL
@@ -1555,7 +1555,7 @@
 Warnings:
 Error	1292	Truncated incorrect DECIMAL value: ''
 Error	1292	Truncated incorrect DECIMAL value: ''
-Warning	1301	Result of rpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of rpad() was larger than max_allowed_packet (67108864) - truncated
 select lpad('hello', -1, '1');
 lpad('hello', -1, '1')
 NULL
@@ -1566,7 +1566,7 @@
 lpad('hello', 4294967295, '1')
 NULL
 Warnings:
-Warning	1301	Result of lpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of lpad() was larger than max_allowed_packet (67108864) - truncated
 select lpad('hello', -4294967296, '1');
 lpad('hello', -4294967296, '1')
 NULL
@@ -1574,7 +1574,7 @@
 lpad('hello', 4294967296, '1')
 NULL
 Warnings:
-Warning	1301	Result of lpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of lpad() was larger than max_allowed_packet (67108864) - truncated
 select lpad('hello', -4294967297, '1');
 lpad('hello', -4294967297, '1')
 NULL
@@ -1582,7 +1582,7 @@
 lpad('hello', 4294967297, '1')
 NULL
 Warnings:
-Warning	1301	Result of lpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of lpad() was larger than max_allowed_packet (67108864) - truncated
 select lpad('hello', -18446744073709551615, '1');
 lpad('hello', -18446744073709551615, '1')
 NULL
@@ -1593,7 +1593,7 @@
 lpad('hello', 18446744073709551615, '1')
 NULL
 Warnings:
-Warning	1301	Result of lpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of lpad() was larger than max_allowed_packet (67108864) - truncated
 select lpad('hello', -18446744073709551616, '1');
 lpad('hello', -18446744073709551616, '1')
 NULL
@@ -1606,7 +1606,7 @@
 Warnings:
 Error	1292	Truncated incorrect DECIMAL value: ''
 Error	1292	Truncated incorrect DECIMAL value: ''
-Warning	1301	Result of lpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of lpad() was larger than max_allowed_packet (67108864) - truncated
 select lpad('hello', -18446744073709551617, '1');
 lpad('hello', -18446744073709551617, '1')
 NULL
@@ -1619,7 +1619,7 @@
 Warnings:
 Error	1292	Truncated incorrect DECIMAL value: ''
 Error	1292	Truncated incorrect DECIMAL value: ''
-Warning	1301	Result of lpad() was larger than max_allowed_packet (1048576) - truncated
+Warning	1301	Result of lpad() was larger than max_allowed_packet (67108864) - truncated
 SELECT CHAR(0xff,0x8f);
 CHAR(0xff,0x8f)
 

=== modified file 'tests/r/mysql_protocol.result'
--- tests/r/mysql_protocol.result	2010-09-29 20:40:25 +0000
+++ tests/r/mysql_protocol.result	2010-10-26 23:46:28 +0000
@@ -8,7 +8,7 @@
 CREATE TABLE `t1` (
   `a` INT DEFAULT NULL,
   KEY `a` (`a`)
-) ENGINE=InnoDB COLLATE = utf8_general_ci;
+) ENGINE='InnoDB' COLLATE='utf8_general_ci';
 
 ALTER TABLE `t1` DISABLE KEYS;
 INSERT INTO `t1` VALUES (1),(2);

=== modified file 'tests/r/union.result'
--- tests/r/union.result	2010-09-10 10:05:56 +0000
+++ tests/r/union.result	2010-10-26 20:59:40 +0000
@@ -1236,7 +1236,7 @@
 drop tables t1,t2,t3;
 SELECT @tmp_max:= @@max_allowed_packet;
 @tmp_max:= @@max_allowed_packet
-1048576
+67108864
 SET max_allowed_packet=25000000;
 CREATE TABLE t1 (a mediumtext);
 CREATE TABLE t2 (b varchar(20));

